pub struct Ticker {
pub symbol: String,
pub bid: f64,
pub bid_size: f64,
pub ask: f64,
pub ask_size: f64,
pub daily_change: f64,
pub daily_change_relative: f64,
pub last_price: f64,
pub volume: f64,
pub high: f64,
pub low: f64,
}Expand description
Represents spot ticker data from the Bitfinex API.
Ticker struct contains fields matching those returned by the Bitfinex API
for spot ticker events. It serves as an interface for JSON deserialization
of spot trading market data, supporting both array and object-based responses.
Fields
symbol: StringThe symbol of the requested ticker data (e.g., “tBTCUSD”).
bid: f64Price of last highest bid.
bid_size: f64Sum of the 25 highest bid sizes.
ask: f64Price of last lowest ask.
ask_size: f64Sum of the 25 lowest ask sizes.
daily_change: f64The amount that the last price has changed since yesterday.
daily_change_relative: f64Relative price change since yesterday (*100 for percentage change).
last_price: f64Price of the last trade.
volume: f64Daily volume.
high: f64Daily high.
low: f64Daily low.